@@ -1,3 +1,4 @@
+"""Update datasets metadata."""
 import pathlib
 import shutil
 
@@ -20,6 +21,7 @@ def subcommand(datasets):
 
 
 def main(datasets):
+    """Update datasets metadata."""
     for path in datasets:
         path = pathlib.Path(path)
         dataset = path.stem
@@ -36,6 +38,6 @@ def main(datasets):
         tools.update_grid_metadata(path, dest, entries)
         compressed = tools.compress(dest)
         dest.unlink()
-        shutil.move(compressed, path)
+        shutil.move(str(compressed), str(path))
 
         rich.print(f"'{path}'\n\tgrid metadata updated")
